#!/usr/bin/env python
# -*- mode:Python; tab-width: 4 -*-
"""
Small hack for Etxebide css files. Makes absolute urls by hand in
all .css files. Also copies static data from post_etxebide_data.
"""

import re
import glob
import os
import shutil
import cms_freeze
import css_parser


__author__ = "Grzegorz Adam Hankiewicz <gradha@efaber.net>"
__date__ = "Jul 2003"
__version__ = "$Revision: 1.3 $"
__credits__ = ""


post_etxebide_data = "post_etxebide_data"
hard_prefix = "/etxebide/html"
use_extension = ".css"
search_path = re.compile(r"/images/(.*)")
image_directory = "images"


def main(directory, extension):
    """Entry point of the appliaction."""
    for file, dummy in cms_freeze.walk_local_files(extension, directory):
        process_css(file, hard_prefix)
    # now the data copying
    dir = os.path.join(directory, image_directory)
    for file in glob.glob(os.path.join(post_etxebide_data, "*gif")):
        destination = os.path.join(dir, os.path.basename(file))
        print "%s -> %s" % (file, destination)
        shutil.copyfile(file, destination)
        
    for file in glob.glob(os.path.join(post_etxebide_data, "*htm")):
        destination = os.path.join(directory, os.path.basename(file))
        print "%s -> %s" % (file, destination)
        shutil.copyfile(file, destination)

    try:
        os.unlink(os.path.join(directory, "cms_freeze_log.txt"))
        print "Borrado", os.path.join(directory, "cms_freeze_log.txt")
    except OSError:
        pass

    print "Done"


def process_css(filename, root_prefix):
    """Makes all images and data links absolute relative to server."""
    print "Searching non absolute links in", filename
    input = file(filename, "rt")
    l = css_parser.Link_extractor(input.read())
    input.close()
    substitutions = {}
    for link in l.get_links():
        match = search_path.search(link)
        if not match:
            continue

        destination = "%s/images/%s " % (root_prefix, match.group(1).strip())
        print "\tde `%s' a `%s'" % (link, destination)
        substitutions[link] = destination

    # ok, make changes if links were found
    if not substitutions:
        return

    t = css_parser.Link_transformer(filename, "", substitutions, 0, 1, 0)
    output = file(filename, "wb")
    output.write(t.get_data())
    output.close()
    

if __name__ == "__main__":
    import sys
    if "run" in sys.argv[1:]:
        main("etxebide", use_extension)
    else:
        print """
Small hack for Etxebide css files. Makes absolute urls by hand in
all .css files. Also copies static data from post_etxebide_data.
All the useful values are hardcoded. Usually you will be running
this after freeze_etxebide.py.

To run this script for real, you have to pass the parameter
"run". Otherwise only this boring screen is printed. Don't worry
about running this script multiple times, that's harmless.
"""
